tietools.TieSpanner
===================

.. abjad-lineage:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner

.. autoclass:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.written_duration
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.append
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.clear
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.extend
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.index
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.pop
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.tietools.TieSpanner.TieSpanner.TieSpanner.__repr__
   :noindex:
